/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.rechargerecord.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.annotation.CommonNoRepeat;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.rechargerecord.entity.BizRechargeRecord;
import vip.xiaonuo.biz.modular.rechargerecord.param.BizRechargeRecordAddParam;
import vip.xiaonuo.biz.modular.rechargerecord.param.BizRechargeRecordIdParam;
import vip.xiaonuo.biz.modular.rechargerecord.param.BizRechargeRecordPageParam;
import vip.xiaonuo.biz.modular.rechargerecord.service.BizRechargeRecordService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;

import java.util.List;
import java.util.Map;

/**
 * 充值记录表控制器
 *
 * @author wulei
 * @date 2025/02/06 17:41
 */
@Tag(name = "充值记录表控制器")
@RestController
@Validated
public class BizRechargeRecordController {

    @Resource
    private BizRechargeRecordService bizRechargeRecordService;

    /**
     * 获取充值记录表分页
     *
     * @author wulei
     * @date 2025/02/06 17:41
     */
    @Operation(summary = "获取充值记录分页")
    @SaCheckPermission("/biz/rechargerecord/page")
    @GetMapping("/biz/rechargerecord/page")
    public CommonResult<Page<BizRechargeRecord>> page(BizRechargeRecordPageParam bizRechargeRecordPageParam) {
        return CommonResult.data(bizRechargeRecordService.page(bizRechargeRecordPageParam));
    }


    /**
     * 获取用户充值记录表分页
     *
     * @author wulei
     * @date 2025/02/06 17:41
     */
    @Operation(summary = "获取用户充值记录分页")
    @GetMapping("/biz/rechargerecord/userPage")
    public CommonResult<Page<BizRechargeRecord>> userPage(BizRechargeRecordPageParam bizRechargeRecordPageParam) {
        return CommonResult.data(bizRechargeRecordService.userPage(bizRechargeRecordPageParam));
    }


    /**
     * 添加充值记录表
     *
     * @author wulei
     * @date 2025/02/06 17:41
     */
    @Operation(summary = "添加充值记录表")
    @CommonLog("添加充值记录表")
    @PostMapping("/biz/rechargerecord/add")
    @CommonNoRepeat
    public CommonResult<Map<String, Object>> add(@RequestBody @Valid BizRechargeRecordAddParam bizRechargeRecordAddParam) {
        return CommonResult.data(bizRechargeRecordService.add(bizRechargeRecordAddParam));
    }

//    /**
//     * 编辑充值记录表
//     *
//     * @author wulei
//     * @date  2025/02/06 17:41
//     */
//    @Operation(summary = "编辑充值记录表")
//    @CommonLog("编辑充值记录表")
//    @SaCheckPermission("/biz/rechargerecord/edit")
//    @PostMapping("/biz/rechargerecord/edit")
//    public CommonResult<String> edit(@RequestBody @Valid BizRechargeRecordEditParam bizRechargeRecordEditParam) {
//        bizRechargeRecordService.edit(bizRechargeRecordEditParam);
//        return CommonResult.ok();
//    }

    /**
     * 删除充值记录表
     *
     * @author wulei
     * @date 2025/02/06 17:41
     */
    @Operation(summary = "删除充值记录表")
    @CommonLog("删除充值记录表")
    @PostMapping("/biz/rechargerecord/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       List<BizRechargeRecordIdParam> bizRechargeRecordIdParamList) {
        bizRechargeRecordService.delete(bizRechargeRecordIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取充值记录表详情
     *
     * @author wulei
     * @date 2025/02/06 17:41
     */
    @Operation(summary = "获取充值记录表详情")
    @GetMapping("/biz/rechargerecord/detail")
    public CommonResult<BizRechargeRecord> detail(@Valid BizRechargeRecordIdParam bizRechargeRecordIdParam) {
        return CommonResult.data(bizRechargeRecordService.detail(bizRechargeRecordIdParam));
    }
}
