/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.biz.modular.userfundchangerecord.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Operation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.biz.modular.userfundchangerecord.entity.BizUserFundChangeRecord;
import vip.xiaonuo.biz.modular.userfundchangerecord.param.BizUserFundChangeRecordAddParam;
import vip.xiaonuo.biz.modular.userfundchangerecord.param.BizUserFundChangeRecordEditParam;
import vip.xiaonuo.biz.modular.userfundchangerecord.param.BizUserFundChangeRecordIdParam;
import vip.xiaonuo.biz.modular.userfundchangerecord.param.BizUserFundChangeRecordPageParam;
import vip.xiaonuo.biz.modular.userfundchangerecord.service.BizUserFundChangeRecordService;

import jakarta.annotation.Resource;
import jakarta.validation.Valid;
import jakarta.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 用户账户资金变动记录控制器
 *
 * @author wulei
 * @date  2025/02/07 11:26
 */
@Tag(name = "用户账户资金变动记录控制器")
@RestController
@Validated
public class BizUserFundChangeRecordController {

    @Resource
    private BizUserFundChangeRecordService bizUserFundChangeRecordService;

    /**
     * 获取用户账户资金变动记录分页
     *
     * @author wulei
     * @date  2025/02/07 11:26
     */
    @Operation(summary = "获取用户账户资金变动记录分页")
    @GetMapping("/biz/userfundchangerecord/page")
    public CommonResult<Page<BizUserFundChangeRecord>> page(BizUserFundChangeRecordPageParam bizUserFundChangeRecordPageParam) {
        return CommonResult.data(bizUserFundChangeRecordService.page(bizUserFundChangeRecordPageParam));
    }

    /**
     * 获取用户账户资金变动记录详情
     *
     * @author wulei
     * @date  2025/02/07 11:26
     */
    @Operation(summary = "获取用户账户资金变动记录详情")
    @GetMapping("/biz/userfundchangerecord/detail")
    public CommonResult<BizUserFundChangeRecord> detail(@Valid BizUserFundChangeRecordIdParam bizUserFundChangeRecordIdParam) {
        return CommonResult.data(bizUserFundChangeRecordService.detail(bizUserFundChangeRecordIdParam));
    }
}
